Network events
--------------

Clients can register callbacks that are executed whenever some event in a
network occurs.  Events that can be observed are adding a node, modifying a
node, and deleting a node.

**Header:** ``mockturtle/networks/events.hpp``

.. doxygenclass:: mockturtle::network_events
   :members:
